function[setpoint] = controllerPID_POS(qd,obj,t,param)
% Using these current and desired states, we have to compute the desired controls
% The current states are:
%%%%%%%%%%%% Inputs: %%%%%%%%%%%%%%%%%
%
% qd: state and desired state information for the quadrotor 
%
%  qd.pos, qd.vel   position and velocity
%  qd.euler = [roll;pitch;yaw]
%  qd.omega         angular velocity in body frame
% 
%  qd.pos_des, qd.vel_des, qd.acc_des  desired position, velocity, accel
%  qd.yaw_des, qd.yawdot_des
%
% t: current time
%    
% param: various parameters
%  param.I     moment of inertia
%  param.grav  gravitational constant g (9.8...m/s^2)
%  param.mass  mass of the drone
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%% Outputs: %%%%%%%%%%%%%%%%%%
%
% F: total thrust commanded (sum of forces from all rotors)
% M: total torque commanded
% trpy: thrust, roll, pitch, yaw (attitude you want to command!)
% drpy: time derivative of trpy
%% *********************PID CONTROLLER ******************************
%position
Kp = 1*[15;15;30];
Kd = 1*[17;12;10];


%High level control: Anti Collision for pilot override
%wall = Box([0;20;0], [20;20;0], [20;20;20], 0.01);
%wall2 = Box([0;0;0], [0;20;0], [0;20;20], 0.01);
%sens_rng = 5;
%dist_to_wall =  wall.distanceTo(qd.pos);
%if dist_to_wall < sens_rng - 2
%    qd.pos_d(1:2) = qd.pos(1:2);
    %desired_state = qd.pos_d;
%end


%PID Low level control: Desired acceleration
% The acc_d is supposed to be given from the colav algorithm
% Position (pos_d) comes indirectly from the desired velocity (vel_d) and a time delay appears 
acc_d = qd.acc_d + Kd.*(qd.vel_d - qd.vel) + Kp.*(qd.pos_d - qd.pos);
%roll, pitch, yaw
phi_d = sat(1/param.grav*(acc_d(1)*sin(qd.yaw_d)-acc_d(2)*cos(qd.yaw_d)),(45*pi/180));
theta_d = sat(1/param.grav*(acc_d(1)*cos(qd.yaw_d)+acc_d(2)*sin(qd.yaw_d)),(45*pi/180));
psi_d = qd.yaw_d;

euler_d = [phi_d; theta_d; psi_d];
setpoint = [euler_d; acc_d(3)];
end