function param = phyfile()
% This function creates a struct with the basic parameters for the
% phyfile quad rotor
%
% Model assumptions based on physical measurements:
%
% total weight of 2.5 kg
% height of 0.1m
% arm length of mass point: 0.25m from center


m = 2.5;  % weight (in kg) inclusive payload 
g = 9.81;   % gravitational constant
I = [1.43e-5,   0,          0; % inertial tensor in m^2 kg
     0,         1.43e-5,    0;
     0,         0,          2.89e-5];
L = 0.25; % arm length in m

param.mass = m;
param.I    = I;
param.invI = inv(I);
param.grav = g;
param.arm_length = L;
param.rotor_radius = 0.10;

param.maxangle = 40*pi/180; % you can specify the maximum commanded angle here
param.maxF     = 2.5*m*g;   % left these untouched from the nano plus
param.minF     = 0.05*m*g;  % left these untouched from the nano plus
param.maxV = 3;
param.maxA = 1.5;
% You can add any fields you want in param
% for example you can add your controller gains by
% param.k = 0, and they will be passed into controller.m

end