function sDot = quadEOM(t, s, controlhandle, trajhandle, param, obj, setpoint)
% QUADEOM Wrapper function for solving quadrotor equation of motion
% 	quadEOM takes in time, state vector, controller, trajectory generator
% 	and parameters and output the derivative of the state vector, the
% 	actual calcution is done in quadEOM_readonly.
%
% INPUTS:
% t             - 1 x 1, time
% s             - 13 x 1, state vector = [x, y, z, xd, yd, zd, qw, qx, qy, qz, p, q, r]
% controlhandle - function handle of your controller
% trajhandle    - function handle of your trajectory generator
% params        - struct, output from crazyflie() and whatever parameters you want to pass in
%
% OUTPUTS:
% sdot          - 13 x 1, derivative of state vector s
%
% NOTE: You should not modify this function
% See Also: quadEOM_readonly, phyfile

% convert state to quad stuct for control
qd = stateToQd(s);

% Get desired_state
desired_state = trajhandle(t);

% The desired_state is set in the trajectory generator
qd.pos_d      = desired_state.pos;
qd.vel_d      = desired_state.vel;
qd.acc_d      = desired_state.acc;
qd.yaw_d      = desired_state.yaw;
qd.yawDot_d   = desired_state.yawDot;
% get control outputs
[F, M, trpy, drpy] = controlhandle(qd, obj, t, param, setpoint);

% compute derivative
sDot = quadEOM_readonly(t, s, F, M, param);

end
